import dspy

from fi.integrations.otel import DSPyInstrumentor, register
from fi.test.eval_tags import eval_tags

# Configure trace provider with custom evaluation tags
trace_provider = register(
    project_name="DSPY_TEST",
    project_version_name="V3",
    eval_tags=eval_tags,
)

# Instrument DSPy with the trace provider
DSPyInstrumentor().instrument(tracer_provider=trace_provider)


class BasicQA(dspy.Signature):
    answer = dspy.OutputField(desc="often between 1 and 5 words")


class RAG(dspy.Module):
    def __init__(self, num_passages=3):
        super().__init__()
        self.retrieve = dspy.Retrieve(k=num_passages)
        self.generate_answer = dspy.ChainOfThought(BasicQA)

    def forward(self, question):
        context = self.retrieve(question).passages
        prediction = self.generate_answer(context=context, question=question)
        return dspy.Prediction(context=context, answer=prediction.answer)


if __name__ == "__main__":
    turbo = dspy.LM("openai/gpt-4", cache=False)
    colbertv2_wiki17_abstracts = dspy.ColBERTv2(
        url="http://20.102.90.50:2017/wiki17_abstracts"
    )
    dspy.settings.configure(
        lm=turbo,
        rm=colbertv2_wiki17_abstracts,
    )
    rag = RAG()
    output = rag("What's the capital of the united states?")
    print(output)
