"""
Requires a Cohere API request set with the `COHERE_API_KEY` environment variable.
"""

from haystack import Document, Pipeline
from haystack_integrations.components.rankers.cohere import CohereRanker

from fi.integrations.otel import HaystackInstrumentor, register
from fi.test.eval_tags import eval_tags

# Configure trace provider with custom evaluation tags
trace_provider = register(
    project_name="HAYSTACK_TEST",
    project_version_name="V2",
    eval_tags=eval_tags,
)

# Initialize the Haystack instrumentor
HaystackInstrumentor().instrument(tracer_provider=trace_provider)

ranker = CohereRanker()
pipe = Pipeline()
pipe.add_component("ranker", ranker)
response = pipe.run(
    {
        "ranker": {
            "query": "Who won the World Cup in 2022?",
            "documents": [
                Document(
                    content="Paul Graham is the founder of Y Combinator.",
                ),
                Document(
                    content=(
                        "Lionel Messi, captain of the Argentinian national team, "
                        " won his first World Cup in 2022."
                    ),
                ),
                Document(
                    content="France lost the 2022 World Cup.",
                ),  # Cohere consistently ranks this document last
            ],
            "top_k": 2,
        }
    }
)
print(f"{response=}")
