from haystack import Pipeline
from haystack.components.builders import PromptBuilder
from haystack.components.converters import HTMLToDocument
from haystack.components.fetchers import LinkContentFetcher
from haystack.components.generators import OpenAIGenerator

from fi.integrations.otel import HaystackInstrumentor, register
from fi.test.eval_tags import eval_tags

# Configure trace provider with custom evaluation tags
trace_provider = register(
    project_name="HAYSTACK_TEST",
    project_version_name="V7",
    eval_tags=eval_tags,
)

# Initialize the Haystack instrumentor
HaystackInstrumentor().instrument(tracer_provider=trace_provider)


fetcher = LinkContentFetcher()
converter = HTMLToDocument()
prompt_template = """
According to the contents of this website:
{% for document in documents %}
  {{document.content}}
{% endfor %}
Answer the given question: {{query}}
Answer:
"""
prompt_builder = PromptBuilder(template=prompt_template)
llm = OpenAIGenerator()

pipeline = Pipeline()
pipeline.add_component("fetcher", fetcher)
pipeline.add_component("converter", converter)
pipeline.add_component("prompt", prompt_builder)
pipeline.add_component("llm", llm)

pipeline.connect("fetcher.streams", "converter.sources")
pipeline.connect("converter.documents", "prompt.documents")
pipeline.connect("prompt.prompt", "llm.prompt")

result = pipeline.run(
    {
        "fetcher": {"urls": ["https://haystack.deepset.ai/overview/quick-start"]},
        "prompt": {"query": "Which components do I need for a RAG pipeline?"},
    }
)

print(result["llm"]["replies"][0])
