import instructor
from openai import OpenAI
from pydantic import BaseModel

from fi.integrations.otel import InstructorInstrumentor, register
from fi.test.eval_tags import eval_tags

# Configure trace provider with custom evaluation tags
trace_provider = register(
    project_name="INSTRUCTOR_TEST",
    project_version_name="V1",
    eval_tags=eval_tags,
)


# Define the output structure
class UserInfo(BaseModel):
    name: str
    age: int


# Patch the OpenAI clientos
client = instructor.patch(client=OpenAI())

InstructorInstrumentor().instrument(tracer_provider=trace_provider)

# Extract structured data from natural language
user_info = client.chat.completions.create(
    model="gpt-3.5-turbo",
    response_model=UserInfo,
    messages=[
        {
            "role": "system",
            "content": "Extract the name and age from the text and return them in a structured format.",
        },
        {"role": "user", "content": "John Doe is nine years old."},
    ],
)

print(user_info, type(user_info))
