import requests
from langchain import agents
from langchain.tools import tool
from langchain_core.prompts import ChatPromptTemplate
from langchain_openai import ChatOpenAI

from fi.integrations.otel import LangChainInstrumentor, register
from fi.test.eval_tags import eval_tags

# Configure trace provider with custom evaluation tags
trace_provider = register(
    project_name="LANGCHAIN_TEST",
    project_version_name="V4",
    eval_tags=eval_tags,
)

# Initialize the LangChain instrumentor
LangChainInstrumentor().instrument(tracer_provider=trace_provider)


@tool
def get_exchange_rate(
    currency_from: str = "USD",
    currency_to: str = "EUR",
    currency_date: str = "latest",
):
    """Retrieves the exchange rate between two currencies on a specified date."""
    return requests.get(
        f"https://api.frankfurter.app/{currency_date}",
        params={"from": currency_from, "to": currency_to},
    ).json()


tools = [get_exchange_rate]
llm = ChatOpenAI()
prompt = ChatPromptTemplate.from_messages(
    [
        ("human", "{input}"),
        ("placeholder", "{agent_scratchpad}"),
    ]
)
agent = agents.create_tool_calling_agent(llm, tools, prompt)
agent_executor = agents.AgentExecutor(agent=agent, tools=tools, verbose=True)

if __name__ == "__main__":
    agent_executor.invoke(
        {
            "input": "What is the exchange rate from US dollars to Swedish currency today?"
        }
    )
