import ssl
import tempfile
from urllib.request import urlretrieve

from llama_index.core import Settings, SimpleDirectoryReader, VectorStoreIndex
from llama_index.llms.openai import OpenAI

from fi.integrations.otel import LlamaIndexInstrumentor, register
from fi.test.eval_tags import eval_tags

# Configure SSL context globally
ssl._create_default_https_context = ssl._create_unverified_context

# Configure trace provider with custom evaluation tags
trace_provider = register(
    project_name="LLAMA_INDEX_TEST",
    project_version_name="V2",
    eval_tags=eval_tags,
)

# Initialize the Llama Index instrumentor
LlamaIndexInstrumentor().instrument(tracer_provider=trace_provider)

# Use context manager for temporary file
with tempfile.NamedTemporaryFile() as tf:
    urlretrieve(
        "https://raw.githubusercontent.com/run-llama/llama_index/main/docs/docs/examples/data/paul_graham/paul_graham_essay.txt",
        tf.name,
    )
    documents = SimpleDirectoryReader(input_files=[tf.name]).load_data()

    index = VectorStoreIndex.from_documents(documents)
    Settings.llm = OpenAI(model="gpt-3.5-turbo")
    chat_engine = index.as_chat_engine()

    if __name__ == "__main__":
        response = chat_engine.stream_chat("What did the author do growing up?")
        response.print_response_stream()
