import asyncio
import os

from mistralai import Mistral

from fi.integrations.otel import MistralAIInstrumentor, register
from fi.test.eval_tags import eval_tags

# Configure trace provider with custom evaluation tags
trace_provider = register(
    project_name="MISTRAL_AI_TEST",
    project_version_name="V2",
    eval_tags=eval_tags,
)

# Initialize the Mistral AI instrumentor
MistralAIInstrumentor().instrument(tracer_provider=trace_provider)


async def run_async_streaming_chat_completion() -> None:
    client = Mistral(api_key=os.environ["MISTRAL_API_KEY"])
    response_stream = await client.chat.stream_async(
        model="mistral-small-latest",
        messages=[
            {
                "content": "Who won the World Cup in 2018?",
                "role": "user",
            },
        ],
    )
    async for chunk in response_stream:
        print(chunk)
    print()


if __name__ == "__main__":
    asyncio.run(run_async_streaming_chat_completion())
