import asyncio

import openai

from fi.integrations.otel import OpenAIInstrumentor, register
from fi.integrations.otel.instrumentation import using_attributes
from fi.test.eval_tags import eval_tags

# Configure trace provider with custom evaluation tags
trace_provider = register(
    project_name="OPENAI_TEST",
    project_version_name="V2",
    eval_tags=eval_tags,
)

# Initialize the OpenAI instrumentor
OpenAIInstrumentor().instrument(tracer_provider=trace_provider)


async def chat_completions(**kwargs):
    client = openai.AsyncOpenAI()
    with using_attributes(
        session_id="my-test-session",
        user_id="my-test-user",
        metadata={
            "test-int": 1,
            "test-str": "string",
            "test-list": [1, 2, 3],
            "test-dict": {
                "key-1": "val-1",
                "key-2": "val-2",
            },
        },
        tags=["tag-1", "tag-2"],
        prompt_template="Who won the soccer match in {city} on {date}",
        prompt_template_version="v1.0",
        prompt_template_variables={
            "city": "Johannesburg",
            "date": "July 11th",
        },
    ):
        response = await client.chat.completions.create(**kwargs)
        async for chunk in response:
            if chunk.choices and (content := chunk.choices[0].delta.content):
                print(content, end="")


if __name__ == "__main__":
    asyncio.run(
        chat_completions(
            model="gpt-3.5-turbo",
            messages=[{"role": "user", "content": "Write a haiku."}],
            max_tokens=20,
            stream=True,
            stream_options={"include_usage": True},
        ),
    )
